Description Usage Arguments Details
Objective Function of Feature Grouping and Sparse PCA with L2 loss.
1 2 3 4 5 6 7 8 9 10 11 | ObjFun_FG_S_PCA_L2(
x,
A,
B,
tau_S,
lambda1,
lambda2 = 0.1,
lambda3 = 0.1,
nnConstraint = FALSE,
sparseTruncated = TRUE
)
|
x |
the data matrix X_{n\times p}, where n is the number of observations, p is the number of features. |
A |
matrix A in the FGSPCA problem |
B |
matrix B in the FGSPCA problem |
tau_S |
τ, a global τ, which is assigned to τ_1=τ_2=τ . |
lambda1 |
λ_1, the tuning parameter corresponding to p_1(\cdot) |
lambda2 |
λ_2, the tuning parameter corresponding to p_2(\cdot) |
lambda3 |
λ_3, the tuning parameter corresponding to p_3(\cdot) |
nnConstraint |
Boolean, indicating the non-negative constraint is true or false, default |
sparseTruncated |
Boolean, indicating whether to use the truncated L1 penalty or not for sparsity,
default |
The L2 loss is defined as follows
(X - X B A^T)^2 .
The penalty function with three parts is defined as follows,
Ψ(β) = λ_{1}p_1(β) + λ_{2}p_2(β) + λ_{3}p_3(β)
where
p_1(β) = ∑_{j=1}^p \min\{\frac{|β_j|}{τ_1}, 1\} ,
p_2(β) = ∑_{j < j', (j, j') \in E} \min\{\frac{|β_j - β_{j'}|}{τ_2}, 1\},
p_3(β) = ∑_{j=1}^p (\min\{β_j, 0\})^2 .
With the setting of lambda2=0, nnConstraint=FALSE, sparseTruncated=FALSE,
it corresponds to the same objective function of sparse PCA; \
ObjFun_FG_S_PCA_L2(x, A, B, tau_S, lambda1, lambda2=0, lambda3=0.1, nnConstraint=FALSE, sparseTruncated=FALSE
With setting of lambda2=0, nnConstraint=FALSE, sparseTruncated=TRUE,
corresponds to Objective function of truncated sparse PCA. \
ObjFun_FG_S_PCA_L2(x, A, B, tau_S, lambda1, lambda2=0, lambda3=0.1, nnConstraint=FALSE, sparseTruncated=TRUE
By tuning the different setting of lambda2, nnConstraint, sparseTruncated,
we get different combination of models.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.